@@ -214,6 +214,12 @@ static int DirContainer_ReallocPiecesOfDir(DirContainer *dirContainer);
 static void DirContainer_FreePiecesOfDirectory(DirContainer *dirContainer);
 static int DirContainer_CopyPiecesOfDirectory(
 	DirContainer *dstDirList, DirContainer *srcDirList);
+static int DirContainer_CopyDirName(
+	PieceOfDirectory *dstDir, PieceOfDirectory *srcDir);
+static int DirContainer_CopyChildDirIndex(
+	PieceOfDirectory *dstDir, PieceOfDirectory *srcDir);
+static int DirContainer_CopyFileIndex(
+	PieceOfDirectory *dstDir, PieceOfDirectory *srcDir);
 
 
 DirContainer *DirContainer_Create(void)
@@ -327,15 +333,89 @@ void DirContainer_FreePiecesOfDirectory(DirContainer *dirContainer)
 }
 
 
+int DirContainer_CopyDirName(
+	PieceOfDirectory *dstDir, PieceOfDirectory *srcDir)
+{
+	int length;
+	char *dirNameTemp;
+	
+	if (srcDir->dirName) {
+		length = strlen(srcDir->dirName);
+		dirNameTemp = (char*)malloc(length + 1);
+		if (dirNameTemp == NULL) {
+			return ARCHIVE_ERROR_ALLOCATE;
+		}
+		dstDir->dirName = dirNameTemp;
+		strcpy(dstDir->dirName, srcDir->dirName);
+	} else {
+		dstDir->dirName = NULL;
+	}
+	
+	return ARCHIVE_SUCCESS;
+}
+
+
+int DirContainer_CopyChildDirIndex(
+	PieceOfDirectory *dstDir, PieceOfDirectory *srcDir)
+{
+	int needSize;
+	int *childDirIndexTemp;
+	
+	if (srcDir->childDirIndex) {
+		needSize = sizeof(int) * srcDir->childDirIndexAllocated;
+		childDirIndexTemp = (int*)malloc(needSize);
+		if (childDirIndexTemp == NULL) {
+			return ARCHIVE_ERROR_ALLOCATE;
+		}
+		dstDir->childDirIndex = childDirIndexTemp;
+		memcpy(
+			dstDir->childDirIndex, srcDir->childDirIndex,
+			sizeof(int) * srcDir->childDirIndexNum);
+		dstDir->childDirIndexNum = srcDir->childDirIndexNum;
+		dstDir->childDirIndexAllocated = srcDir->childDirIndexAllocated;
+	} else {
+		dstDir->childDirIndex = NULL;
+		dstDir->childDirIndexNum = srcDir->childDirIndexNum;
+		dstDir->childDirIndexAllocated = srcDir->childDirIndexAllocated;
+	}
+	
+	return ARCHIVE_SUCCESS;
+}
+
+
+int DirContainer_CopyFileIndex(
+	PieceOfDirectory *dstDir, PieceOfDirectory *srcDir)
+{
+	int needSize;
+	int *fileIndexTemp;
+	
+	if (srcDir->fileIndex) {
+		needSize = sizeof(int) * srcDir->fileIndexAllocated;
+		fileIndexTemp = (int*)malloc(needSize);
+		if (fileIndexTemp == NULL) {
+			return ARCHIVE_ERROR_ALLOCATE;
+		}
+		dstDir->fileIndex = fileIndexTemp;
+		memcpy(
+			dstDir->fileIndex, srcDir->fileIndex,
+			sizeof(int) * srcDir->fileIndexNum);
+		dstDir->fileIndexNum = srcDir->fileIndexNum;
+		dstDir->fileIndexAllocated = srcDir->fileIndexAllocated;
+	} else {
+		dstDir->fileIndex = NULL;
+		dstDir->fileIndexNum = srcDir->fileIndexNum;
+		dstDir->fileIndexAllocated = srcDir->fileIndexAllocated;
+	}
+	
+	return ARCHIVE_SUCCESS;
+}
+
+
 int DirContainer_CopyPiecesOfDirectory(
 	DirContainer *dstDirList, DirContainer *srcDirList)
 {
 	int i;
-	int length;
-	char *dirNameTemp;
-	int *childDirIndexTemp;
-	int *fileIndexTemp;
-	int needSize;
+	int result;
 	
 	for (i = 0; i < dstDirList->dirNum; i++) {
 		dstDirList->piecesOfDir[i].dirName = NULL;
@@ -343,58 +423,29 @@ int DirContainer_CopyPiecesOfDirectory(
 		dstDirList->piecesOfDir[i].fileIndex = NULL;
 	}
 	for (i = 0; i < srcDirList->dirNum; i++) {
-		length = strlen(srcDirList->piecesOfDir[i].dirName);
-		dirNameTemp = (char*)malloc(length + 1);
-		if (dirNameTemp == NULL) {
+		result = DirContainer_CopyDirName(
+			&dstDirList->piecesOfDir[i],
+			&srcDirList->piecesOfDir[i]);
+		if (result != ARCHIVE_SUCCESS) {
 			DirContainer_FreePiecesOfDirectory(dstDirList);
-			return ARCHIVE_ERROR_ALLOCATE;
+			return result;
 		}
-		dstDirList->piecesOfDir[i].dirName =
-			dirNameTemp;
-		strcpy(
-			dstDirList->piecesOfDir[i].dirName,
-			srcDirList->piecesOfDir[i].dirName);
 		
-		needSize =
-			sizeof(int) *
-			srcDirList->piecesOfDir[i].childDirIndexAllocated;
-		childDirIndexTemp = (int*)malloc(needSize);
-		if (childDirIndexTemp == NULL) {
+		result = DirContainer_CopyChildDirIndex(
+			&dstDirList->piecesOfDir[i],
+			&srcDirList->piecesOfDir[i]);
+		if (result != ARCHIVE_SUCCESS) {
 			DirContainer_FreePiecesOfDirectory(dstDirList);
-			return ARCHIVE_ERROR_ALLOCATE;
+			return result;
 		}
-		dstDirList->piecesOfDir[i].childDirIndex =
-			childDirIndexTemp;
-		memcpy(
-			dstDirList->piecesOfDir[i].childDirIndex,
-			srcDirList->piecesOfDir[i].childDirIndex,
-			needSize);
-		dstDirList->piecesOfDir[i].childDirIndexNum =
-			srcDirList->piecesOfDir[i].childDirIndexNum;
-		dstDirList->piecesOfDir[i].childDirIndexAllocated =
-			srcDirList->piecesOfDir[i].childDirIndexAllocated;
 		
-		needSize =
-			sizeof(int) *
-			srcDirList->piecesOfDir[i].fileIndexAllocated;
-		fileIndexTemp = (int*)malloc(needSize);
-		if (fileIndexTemp == NULL) {
+		result = DirContainer_CopyFileIndex(
+			&dstDirList->piecesOfDir[i],
+			&srcDirList->piecesOfDir[i]);
+		if (result != ARCHIVE_SUCCESS) {
 			DirContainer_FreePiecesOfDirectory(dstDirList);
-			return ARCHIVE_ERROR_ALLOCATE;
+			return result;
 		}
-		dstDirList->piecesOfDir[i].fileIndex =
-			fileIndexTemp;
-		memcpy(
-			dstDirList->piecesOfDir[i].fileIndex,
-			srcDirList->piecesOfDir[i].fileIndex,
-			needSize);
-		dstDirList->piecesOfDir[i].fileIndexNum =
-			srcDirList->piecesOfDir[i].fileIndexNum;
-		dstDirList->piecesOfDir[i].fileIndexAllocated =
-			srcDirList->piecesOfDir[i].fileIndexAllocated;
-		
-		dstDirList->piecesOfDir[i].parentDirIndex =
-			srcDirList->piecesOfDir[i].parentDirIndex;
 	}
 	
 	return ARCHIVE_SUCCESS;
