@@ -36,19 +36,20 @@
 typedef struct _file_chain
 {
 	long size;
-	char *filename;
+	char *fileName;
 } FILE_CHAIN;
 
 
 typedef struct _directory_DATA
 {
 	FILE *fp;
-	int chainNum;
+	
 	FILE_CHAIN *chain;
+	int chainNum;
 	int chainAllocated;
 	
-	int tempStringAllocated;
-	char *tempString;
+	int tempPathBufAllocated;
+	char *tempPathBuf;
 	
 	int openNumber;
 	char *dirName;
@@ -58,7 +59,7 @@ typedef struct _directory_DATA
 
 
 static DIRECTORY_DATA *Dir_Create(const char *file);
-static int Dir_GetFileNumByName(SDL_Archive *archive, const char *filename);
+static int Dir_GetFileNumByName(SDL_Archive *archive, const char *fileName);
 static int Dir_OpenFile(SDL_Archive *archive, const char *fileName);
 static int Dir_GetChildDirNum(SDL_Archive *archive);
 static char *Dir_GetChildDirName(SDL_Archive *archive, int dirNum);
@@ -70,6 +71,7 @@ static char *Dir_GetCurrentDirPath(SDL_Archive *archive);
 static long Dir_Size(SDL_Archive *archive);
 static int Dir_GetFileNumber(SDL_Archive *archive);
 static char *Dir_GetFileName(SDL_Archive *archive, int num);
+static void Dir_Free(DIRECTORY_DATA *dir);
 static void Dir_Finish(SDL_Archive *archive);
 static int Dir_GetChar(SDL_Archive *archive);
 static long Dir_Tell(SDL_Archive *archive);
@@ -77,13 +79,13 @@ static int Dir_EOF(SDL_Archive *archive);
 static int Dir_Read(SDL_Archive *archive, void *mem, const int size, const int maxnum);
 static int Dir_Seek(SDL_Archive *archive, const long offset, const int whence);
 static int Dir_Close(SDL_Archive *archive);
-static int Dir_LoadDirectory(DIRECTORY_DATA *data);
-static int Dir_SetTempPath(DIRECTORY_DATA *data, const char *fileName);
+static int Dir_LoadDirectory(DIRECTORY_DATA *dir);
+static int Dir_SetTempPath(DIRECTORY_DATA *dir, const char *fileName);
 static SDL_Archive *Dir_Clone(SDL_Archive *archive);
 
-static int Dir_ReallocChain(DIRECTORY_DATA *data);
-static int Dir_AddFile(DIRECTORY_DATA *data, const char *fileName, int fileSize);
-static int Dir_AddDirectory(DIRECTORY_DATA *data, const char *dirName);
+static int Dir_ReallocChain(DIRECTORY_DATA *dir);
+static int Dir_AddFile(DIRECTORY_DATA *dir, const char *fileName, int fileSize);
+static int Dir_AddDirectory(DIRECTORY_DATA *dir, const char *dirName);
 static int Dir_IsValidDir(const char *name);
 
 
@@ -203,7 +205,7 @@ int Dir_IsValidDir(const char *name)
 }
 
 
-int Dir_SetTempPath(DIRECTORY_DATA *data, const char *fileName)
+int Dir_SetTempPath(DIRECTORY_DATA *dir, const char *fileName)
 {
 	int allocSize;
 	int needSize;
@@ -211,7 +213,7 @@ int Dir_SetTempPath(DIRECTORY_DATA *data, const char *fileName)
 	char *currentPath;
 	int fileNameLength;
 	
-	currentPath = DirContainer_GetCurrentPath(data->dirContainer);
+	currentPath = DirContainer_GetCurrentPath(dir->dirContainer);
 	currentPath = currentPath + 1; /* next '/' */
 	
 	if (fileName) {
@@ -220,48 +222,48 @@ int Dir_SetTempPath(DIRECTORY_DATA *data, const char *fileName)
 		fileNameLength = 0;
 	}
 	/*
-	  data->dirName + delimiter +
+	  dir->dirName + delimiter +
 	  dirName + delimiter +
 	  fileName + '\0'
 	 */
 	needSize =
-		strlen(data->dirName) + 1 +
+		strlen(dir->dirName) + 1 +
 		strlen(currentPath) + 1 +
 		fileNameLength + 1;
-	allocSize = data->tempStringAllocated;
+	allocSize = dir->tempPathBufAllocated;
 	while (allocSize < needSize) {
 		allocSize *= 2;
 	}
 	
-	if (allocSize > data->tempStringAllocated) {
-		tempMem = realloc(data->tempString, allocSize);
+	if (allocSize > dir->tempPathBufAllocated) {
+		tempMem = realloc(dir->tempPathBuf, allocSize);
 		if (tempMem == NULL) {
 			return ARCHIVE_ERROR_ALLOCATE;
 		}
-		data->tempStringAllocated = allocSize;
-		data->tempString = tempMem;
+		dir->tempPathBufAllocated = allocSize;
+		dir->tempPathBuf = tempMem;
 	}
 	
-	strcpy(data->tempString, data->dirName);
+	strcpy(dir->tempPathBuf, dir->dirName);
 	
 	if (currentPath != NULL && currentPath[0] != '\0') {
-		strcat(data->tempString, "/");
-		strcat(data->tempString, currentPath);
+		strcat(dir->tempPathBuf, "/");
+		strcat(dir->tempPathBuf, currentPath);
 	}
 	
 	if (fileName) {
-		strcat(data->tempString, "/");
-		strcat(data->tempString, fileName);
+		strcat(dir->tempPathBuf, "/");
+		strcat(dir->tempPathBuf, fileName);
 	}
 	
 #ifdef WIN32
 	{
 		int i;
 		int stringLength;
-		stringLength = strlen(data->tempString);
+		stringLength = strlen(dir->tempPathBuf);
 		for (i = 0; i < stringLength; i++) {
-			if (data->tempString[i] == '/') {
-				data->tempString[i] = '\\';
+			if (dir->tempPathBuf[i] == '/') {
+				dir->tempPathBuf[i] = '\\';
 			}
 		}
 	}
@@ -271,68 +273,69 @@ int Dir_SetTempPath(DIRECTORY_DATA *data, const char *fileName)
 }
 
 
-int Dir_ReallocChain(DIRECTORY_DATA *data)
+int Dir_ReallocChain(DIRECTORY_DATA *dir)
 {
 	int needSize;
 	void *tempptr;
 	
-	if (data->chainNum >= data->chainAllocated) {
-		needSize = data->chainAllocated * 2;
-		tempptr = realloc(data->chain,
+	if (dir->chainNum >= dir->chainAllocated) {
+		needSize = dir->chainAllocated * 2;
+		tempptr = realloc(
+			dir->chain,
 			sizeof(FILE_CHAIN) * needSize);
 		if (tempptr == NULL) {
 			return ARCHIVE_ERROR_ALLOCATE;
 		}
-		data->chain = (FILE_CHAIN*)tempptr;
-		data->chainAllocated = needSize;
+		dir->chain = (FILE_CHAIN*)tempptr;
+		dir->chainAllocated = needSize;
 	}
 	
 	return ARCHIVE_SUCCESS;
 }
 
 
-int Dir_AddFile(DIRECTORY_DATA *data, const char *fileName, int fileSize)
+int Dir_AddFile(DIRECTORY_DATA *dir, const char *fileName, int fileSize)
 {
 	int result;
 	
-	result = Dir_ReallocChain(data);
+	result = Dir_ReallocChain(dir);
 	if (result != ARCHIVE_SUCCESS) {
 		return result;
 	}
 	
-	data->chain[data->chainNum].filename =
+	dir->chain[dir->chainNum].fileName =
 		malloc(strlen(fileName) + 1);
-	if (data->chain[data->chainNum].filename == NULL) {
+	if (dir->chain[dir->chainNum].fileName == NULL) {
 		return ARCHIVE_ERROR_ALLOCATE;
 	}
-	strcpy(data->chain[data->chainNum].filename, fileName);
-	data->chain[data->chainNum].size = fileSize;
-	DirContainer_AddFile(data->dirContainer, data->chainNum);
-	data->chainNum++;
+	strcpy(dir->chain[dir->chainNum].fileName, fileName);
+	dir->chain[dir->chainNum].size = fileSize;
+	DirContainer_AddFile(dir->dirContainer, dir->chainNum);
+	dir->chainNum++;
 	
 	return ARCHIVE_SUCCESS;
 }
 
 
-int Dir_AddDirectory(DIRECTORY_DATA *data, const char *dirName)
+int Dir_AddDirectory(DIRECTORY_DATA *dir, const char *dirName)
 {
 	int result;
 	
 	result = DirContainer_AddDirectory(
-		data->dirContainer, dirName);
+		dir->dirContainer, dirName);
 	if (result != ARCHIVE_SUCCESS) {
 		return result;
 	}
 	result = DirContainer_GoDownDir(
-		data->dirContainer, dirName);
+		dir->dirContainer, dirName);
 	if (result != ARCHIVE_SUCCESS) {
 		return result;
 	}
-	result = Dir_LoadDirectory(data);
+	result = Dir_LoadDirectory(dir);
 	if (result != ARCHIVE_SUCCESS) {
 		return result;
 	}
-	result = DirContainer_GoUpDir(data->dirContainer);
+	result = DirContainer_GoUpDir(dir->dirContainer);
 	if (result != ARCHIVE_SUCCESS) {
 		return result;
 	}
@@ -341,18 +344,18 @@ int Dir_AddDirectory(DIRECTORY_DATA *data, const char *dirName)
 }
 
 
-int Dir_LoadDirectory(DIRECTORY_DATA *data)
+int Dir_LoadDirectory(DIRECTORY_DATA *dir)
 #ifdef WIN32
 {
 	WIN32_FIND_DATA findFile;
 	HANDLE handle;
 	int result;
 	
-	result = Dir_SetTempPath(data, "*");
+	result = Dir_SetTempPath(dir, "*");
 	if (result != ARCHIVE_SUCCESS) {
 		return result;
 	}
-	handle = FindFirstFile(data->tempString, &findFile);
+	handle = FindFirstFile(dir->tempPathBuf, &findFile);
 	if (handle == INVALID_HANDLE_VALUE) {
 		return ARCHIVE_ERROR_INVALID_NAME;
 	}
@@ -364,17 +367,17 @@ int Dir_LoadDirectory(DIRECTORY_DATA *data)
 			continue;
 		}
 		if (findFile.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY) {
-			result = Dir_AddDirectory(data, findFile.cFileName);
+			result = Dir_AddDirectory(dir, findFile.cFileName);
 			if (result != ARCHIVE_SUCCESS) {
 				return result;
 			}
 		} else {
-			result = Dir_SetTempPath(data, findFile.cFileName);
+			result = Dir_SetTempPath(dir, findFile.cFileName);
 			if (result != ARCHIVE_SUCCESS) {
 				break;
 			}
 			
-			result = Dir_AddFile(data, findFile.cFileName, findFile.nFileSizeLow);
+			result = Dir_AddFile(dir, findFile.cFileName, findFile.nFileSizeLow);
 			if (result != ARCHIVE_SUCCESS) {
 				break;
 			}
@@ -394,11 +397,11 @@ int Dir_LoadDirectory(DIRECTORY_DATA *data)
 	long fileSize;
 	int result;
 	
-	result = Dir_SetTempPath(data, NULL);
+	result = Dir_SetTempPath(dir, NULL);
 	if (result != ARCHIVE_SUCCESS) {
 		return result;
 	}
-	dir = opendir(data->tempString);
+	dir = opendir(dir->tempPathBuf);
 	if (dir == NULL) {
 		return ARCHIVE_ERROR_INVALID_NAME;
 	}
@@ -410,23 +413,23 @@ int Dir_LoadDirectory(DIRECTORY_DATA *data)
 			continue;
 		}
 		
-		result = Dir_SetTempPath(data, ent->d_name);
+		result = Dir_SetTempPath(dir, ent->d_name);
 		if (result != ARCHIVE_SUCCESS) {
 			return result;
 		}
-		tempDir = opendir(data->tempString);
+		tempDir = opendir(dir->tempPathBuf);
 		if (tempDir) {
 			closedir(tempDir);
-			result = Dir_AddDirectory(data, ent->d_name);
+			result = Dir_AddDirectory(dir, ent->d_name);
 			if (result != ARCHIVE_SUCCESS) {
 				return result;
 			}
 		} else {
-			result = Dir_SetTempPath(data, ent->d_name);
+			result = Dir_SetTempPath(dir, ent->d_name);
 			if (result != ARCHIVE_SUCCESS) {
 				break;
 			}
-			fp = fopen(data->tempString, "rb");
+			fp = fopen(dir->tempPathBuf, "rb");
 			if (fp == NULL) {
 				continue;
 			}
@@ -434,7 +437,7 @@ int Dir_LoadDirectory(DIRECTORY_DATA *data)
 			fileSize = ftell(fp);
 			fclose(fp);
 			
-			result = Dir_AddFile(data, ent->d_name, fileSize);
+			result = Dir_AddFile(dir, ent->d_name, fileSize);
 			if (result != ARCHIVE_SUCCESS) {
 				break;
 			}
@@ -450,63 +453,59 @@ int Dir_LoadDirectory(DIRECTORY_DATA *data)
 
 DIRECTORY_DATA *Dir_Create(const char *file)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	int needSize;
 	int result;
 	
-	data = (DIRECTORY_DATA*)malloc(sizeof(DIRECTORY_DATA));
-	if (data == NULL) {
+	dir = (DIRECTORY_DATA*)malloc(sizeof(DIRECTORY_DATA));
+	if (dir == NULL) {
 		return NULL;
 	}
 	
-	data->dirName = (char*)malloc(strlen(file) + 1);
-	if (data->dirName == NULL) {
-		free(data);
+	dir->dirContainer = NULL;
+	dir->tempPathBuf = NULL;
+	dir->dirName = NULL;
+	dir->fp = NULL;
+	dir->chain = NULL;
+	
+	dir->dirName = (char*)malloc(strlen(file) + 1);
+	if (dir->dirName == NULL) {
+		Dir_Free(dir);
 		return NULL;
 	}
-	strcpy(data->dirName, file);
+	strcpy(dir->dirName, file);
 	
 	/* directory name + delimiter + '\0' */
-	needSize = strlen(data->dirName) + 1 + 1;
-	data->tempString = (char*)malloc(needSize);
-	if (data->tempString == NULL) {
-		free(data->dirName);
-		free(data);
+	needSize = strlen(dir->dirName) + 1 + 1;
+	dir->tempPathBuf = (char*)malloc(needSize);
+	if (dir->tempPathBuf == NULL) {
+		Dir_Free(dir);
 		return NULL;
 	}
-	data->tempStringAllocated = needSize;
+	dir->tempPathBufAllocated = needSize;
 	
-	data->dirContainer = DirContainer_Create();
-	if (data->dirContainer == NULL) {
-		free(data->tempString);
-		free(data->dirName);
-		free(data);
+	dir->dirContainer = DirContainer_Create();
+	if (dir->dirContainer == NULL) {
+		Dir_Free(dir);
 		return NULL;
 	}
 	
-	data->chain = (FILE_CHAIN*)malloc(sizeof(FILE_CHAIN) * 1);
-	if (data->chain == NULL) {
-		DirContainer_Free(data->dirContainer);
-		free(data->tempString);
-		free(data->dirName);
-		free(data);
+	dir->chain = (FILE_CHAIN*)malloc(sizeof(FILE_CHAIN) * 1);
+	if (dir->chain == NULL) {
+		Dir_Free(dir);
 		return NULL;
 	}
-	data->fp = NULL;
-	data->chainNum = 0;
-	data->chainAllocated = 1;
+	dir->fp = NULL;
+	dir->chainNum = 0;
+	dir->chainAllocated = 1;
 	
-	result = Dir_LoadDirectory(data);
+	result = Dir_LoadDirectory(dir);
 	if (result != ARCHIVE_SUCCESS) {
-		DirContainer_Free(data->dirContainer);
-		free(data->chain);
-		free(data->tempString);
-		free(data->dirName);
-		free(data);
+		Dir_Free(dir);
 		return NULL;
 	}
 	
-	return data;
+	return dir;
 }
 
 
@@ -515,7 +514,7 @@ SDL_Archive *Dir_Clone(SDL_Archive *orgArchive)
 	SDL_Archive *archive;
 	DIRECTORY_DATA *dir;
 	DIRECTORY_DATA *orgDir;
-	int iDir, iOrgDir;
+	int i;
 	int needSize;
 	
 	orgDir = (DIRECTORY_DATA*)orgArchive->data;
@@ -525,57 +524,56 @@ SDL_Archive *Dir_Clone(SDL_Archive *orgArchive)
 		return NULL;
 	}
 	
+	dir->dirContainer = NULL;
+	dir->tempPathBuf = NULL;
+	dir->dirName = NULL;
+	dir->fp = NULL;
+	dir->chain = NULL;
+	
 	dir->dirName = (char*)malloc(strlen(orgDir->dirName) + 1);
 	if (dir->dirName == NULL) {
-		free(dir);
+		Dir_Free(dir);
 		return NULL;
 	}
 	strcpy(dir->dirName, orgDir->dirName);
 	
 	/* directory name + delimiter + '\0' */
 	needSize = strlen(dir->dirName) + 1 + 1;
-	dir->tempString = (char*)malloc(needSize);
-	if (dir->tempString == NULL) {
-		free(dir->dirName);
-		free(dir);
+	dir->tempPathBuf = (char*)malloc(needSize);
+	if (dir->tempPathBuf == NULL) {
+		Dir_Free(dir);
 		return NULL;
 	}
-	dir->tempStringAllocated = needSize;
+	dir->tempPathBufAllocated = needSize;
 	
 	dir->chain = (FILE_CHAIN*)malloc(
 		sizeof(FILE_CHAIN) * orgDir->chainNum);
 	if (dir->chain == NULL) {
-		free(dir->tempString);
-		free(dir->dirName);
-		free(dir);
+		Dir_Free(dir);
 		return NULL;
 	}
 	dir->chainAllocated = orgDir->chainNum;
 	
 	dir->fp = NULL;
 	
-	iDir = 0;
-	for (iOrgDir = 0; iOrgDir < orgDir->chainNum; iOrgDir++) {
-		needSize = strlen(orgDir->chain[iOrgDir].filename) + 1;
-		dir->chain[iDir].filename = (char*)malloc(needSize);
-		if (dir->chain[iDir].filename == NULL) {
-			continue;
-		}
-		strcpy(dir->chain[iDir].filename,
-			orgDir->chain[iOrgDir].filename);
-		
-		dir->chain[iDir].size = orgDir->chain[iOrgDir].size;
-		
-		iDir++;
+	for (i = 0; i < orgDir->chainNum; i++) {
+		dir->chain[i].fileName = NULL;
 	}
-	dir->chainNum = iDir;
+	for (i = 0; i < orgDir->chainNum; i++) {
+		dir->chain[i].fileName = (char*)malloc(
+			strlen(orgDir->chain[i].fileName) + 1);
+		if (dir->chain[i].fileName == NULL) {
+			Dir_Free(dir);
+			return NULL;
+		}
+		strcpy(dir->chain[i].fileName, orgDir->chain[i].fileName);
+		dir->chain[i].size = orgDir->chain[i].size;
+	}
+	dir->chainNum = orgDir->chainNum;
 	
 	dir->dirContainer = DirContainer_Clone(orgDir->dirContainer);
 	if (dir->dirContainer == NULL) {
-		free(dir->chain);
-		free(dir->tempString);
-		free(dir->dirName);
-		free(dir);
+		Dir_Free(dir);
 		return NULL;
 	}
 	
@@ -583,11 +581,7 @@ SDL_Archive *Dir_Clone(SDL_Archive *orgArchive)
 	
 	archive = Archive_Alloc();
 	if (archive == NULL) {
-		DirContainer_Free(dir->dirContainer);
-		free(dir->chain);
-		free(dir->tempString);
-		free(dir->dirName);
-		free(dir);
+		Dir_Free(dir);
 		return NULL;
 	}
 	
@@ -621,41 +615,52 @@ SDL_Archive *Dir_Clone(SDL_Archive *orgArchive)
 }
 
 
-void Dir_Finish(SDL_Archive *archive)
+void Dir_Free(DIRECTORY_DATA *dir)
 {
 	int i;
-	DIRECTORY_DATA *data;
 	
+	if (dir->dirContainer) {
+		DirContainer_Free(dir->dirContainer);
+	}
+	if (dir->tempPathBuf) {
+		free(dir->tempPathBuf);
+	}
+	if (dir->dirName) {
+		free(dir->dirName);
+	}
+	if (dir->fp != NULL) {
+		fclose(dir->fp);
+	}
+	
+	if (dir->chain) {
+		for (i = 0; i < dir->chainNum; i++) {
+			free(dir->chain[i].fileName);
+		}
+		free(dir->chain);
+	}
+	
+	free(dir);
+}
+
+
+void Dir_Finish(SDL_Archive *archive)
+{
 	if (archive != NULL) {
-		data = archive->data;
-		
-		for (i = 0; i < data->chainNum; i++) {
-			free(data->chain[i].filename);
-		}
-		
-		DirContainer_Free(data->dirContainer);
-		free(data->tempString);
-		free(data->dirName);
-		
-		free(data->chain);
-		if (data->fp != NULL) {
-			fclose(data->fp);
-		}
-		free(data);
+		Dir_Free((DIRECTORY_DATA*)archive->data);
 	}
 	Archive_FreeMainContext(archive);
 }
 
 
-int Dir_GetFileNumByName(SDL_Archive *archive, const char *filename)
+int Dir_GetFileNumByName(SDL_Archive *archive, const char *fileName)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	int i;
 	
-	data = archive->data;
+	dir = archive->data;
 	
-	for (i = 0; i < data->chainNum; i++) {
-		if (strcmp(data->chain[i].filename, filename) == 0) {
+	for (i = 0; i < dir->chainNum; i++) {
+		if (strcmp(dir->chain[i].fileName, fileName) == 0) {
 			return i;
 		}
 	}
@@ -666,34 +671,32 @@ int Dir_GetFileNumByName(SDL_Archive *archive, const char *filename)
 
 int Dir_OpenFile(SDL_Archive *archive, const char *fileName)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	int result;
-	int fileIndex;
 	int num;
 	
-	data = archive->data;
+	dir = archive->data;
 	
 	num = Dir_GetFileNumByName(archive, fileName);
 	
-	if (num < 0 || data->chainNum <= num) {
+	if (num < 0 || dir->chainNum <= num) {
 		return ARCHIVE_ERROR_NO_EXIST_FILE;
 	}
 	
-	if (data->fp != NULL) {
+	if (dir->fp != NULL) {
 		return ARCHIVE_ERROR_ALREADY_OPEN;
 	}
 	
-	fileIndex = DirContainer_GetFileIndex(data->dirContainer, num);
-	result = Dir_SetTempPath(data, data->chain[fileIndex].filename);
+	result = Dir_SetTempPath(dir, dir->chain[num].fileName);
 	if (result != 0) {
 		return result;
 	}
-	data->fp = fopen(data->tempString, "rb");
-	if (data->fp == NULL) {
+	dir->fp = fopen(dir->tempPathBuf, "rb");
+	if (dir->fp == NULL) {
 		return ARCHIVE_ERROR_NO_EXIST_FILE;
 	}
 	
-	data->openNumber = num;
+	dir->openNumber = num;
 	
 	return ARCHIVE_SUCCESS;
 }
@@ -787,79 +790,79 @@ char *Dir_GetFileName(SDL_Archive *archive, int num)
 	dir = (DIRECTORY_DATA*)archive->data;
 	fileIndex = DirContainer_GetFileIndex(dir->dirContainer, num);
 	
-	return dir->chain[fileIndex].filename;
+	return dir->chain[fileIndex].fileName;
 }
 
 
 long Dir_Size(SDL_Archive *archive)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	
-	data = archive->data;
+	dir = archive->data;
 	
-	return data->chain[data->openNumber].size;
+	return dir->chain[dir->openNumber].size;
 }
 
 
 int Dir_GetChar(SDL_Archive *archive)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	
-	data = archive->data;
+	dir = archive->data;
 	
-	return fgetc(data->fp);
+	return fgetc(dir->fp);
 }
 
 
 long Dir_Tell(SDL_Archive *archive)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	
-	data = archive->data;
+	dir = archive->data;
 	
-	return ftell(data->fp);
+	return ftell(dir->fp);
 }
 
 
 int Dir_EOF(SDL_Archive *archive)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	
-	data = archive->data;
+	dir = archive->data;
 	
-	return feof(data->fp);
+	return feof(dir->fp);
 }
 
 
 int Dir_Read(SDL_Archive *archive, void *mem, const int size, const int maxnum)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	
-	data = archive->data;
+	dir = archive->data;
 	
-	return fread(mem, size, maxnum, data->fp);
+	return fread(mem, size, maxnum, dir->fp);
 }
 
 
 int Dir_Seek(SDL_Archive *archive, const long offset, const int whence)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	
-	data = archive->data;
+	dir = archive->data;
 	
-	return fseek(data->fp, offset, whence);
+	return fseek(dir->fp, offset, whence);
 }
 
 
 int Dir_Close(SDL_Archive *archive)
 {
-	DIRECTORY_DATA *data;
+	DIRECTORY_DATA *dir;
 	
-	data = archive->data;
+	dir = archive->data;
 	
-	fclose(data->fp);
-	data->fp = NULL;
-	data->openNumber = -1;
+	fclose(dir->fp);
+	dir->fp = NULL;
+	dir->openNumber = -1;
 	
 	return ARCHIVE_SUCCESS;
 }
