@@ -133,11 +133,11 @@ typedef struct pkzip_data
 	long restDataSize;
 	z_stream z;
 	
-	int fileNum;
-	int allocatedChain;
+	int chainNum;
+	int chainAllocated;
 	INNER_FILE *chain;
 	
-	char *fileName;
+	char *arcName;
 	
 	DirContainer *dirContainer;
 } PKZIP_DATA;
@@ -156,6 +156,7 @@ static char *PKZip_GetCurrentDirPath(SDL_Archive *archive);
 static int PKZip_GetFileNumByName(SDL_Archive *archive, const char *name);
 static int PKZip_GetFileNumber(SDL_Archive *archive);
 static char *PKZip_GetFileName(SDL_Archive *archive, int num);
+static void PKZip_Free(PKZIP_DATA *pkzip);
 static void PKZip_Finish(SDL_Archive *archive);
 static int PKZip_LoadNextHeader(PKZIP_DATA *pkzip);
 static int PKZip_GetEndOfCentralDirectory(
@@ -400,12 +401,12 @@ int PKZip_LoadNextHeader(PKZIP_DATA *pkzip)
 		}
 	}
 	DirContainer_AddFileToDirIndex(
-		pkzip->dirContainer, pkzip->fileNum, dirIndex);
+		pkzip->dirContainer, pkzip->chainNum, dirIndex);
 	
-	pkzip->chain[pkzip->fileNum].seek = centralDir.relativeOffsetOfLocalHeader;
-	pkzip->chain[pkzip->fileNum].fileName = fileName;
+	pkzip->chain[pkzip->chainNum].seek = centralDir.relativeOffsetOfLocalHeader;
+	pkzip->chain[pkzip->chainNum].fileName = fileName;
 	
-	pkzip->fileNum++;
+	pkzip->chainNum++;
 	
 	return 0;
 }
@@ -418,44 +419,44 @@ PKZIP_DATA *PKZip_Create(const char *file)
 	PKZIP_DATA *pkzip;
 	EndOfCentralDirRecordBase endOfCentralDir;
 	void *tempptr;
+	int needSize;
 	
 	pkzip = (PKZIP_DATA*)malloc(sizeof(PKZIP_DATA));
 	if (pkzip == NULL) {
 		return NULL;
 	}
 	
-	pkzip->fileName = (char*)malloc(strlen(file) + 1);
-	if (pkzip->fileName == NULL) {
-		free(pkzip);
+	pkzip->arcName = NULL;
+	pkzip->dirContainer = NULL;
+	pkzip->rw = NULL;
+	pkzip->chain = NULL;
+	
+	pkzip->arcName = (char*)malloc(strlen(file) + 1);
+	if (pkzip->arcName == NULL) {
+		PKZip_Free(pkzip);
 		return NULL;
 	}
-	strcpy(pkzip->fileName, file);
+	strcpy(pkzip->arcName, file);
 	
 	pkzip->dirContainer = DirContainer_Create();
 	if (pkzip->dirContainer == NULL) {
-		free(pkzip->fileName);
-		free(pkzip);
+		PKZip_Free(pkzip);
 		return NULL;
 	}
 	
 	pkzip->rw = SDL_RWFromFile(file, "rb");
 	if (pkzip->rw == NULL) {
-		DirContainer_Free(pkzip->dirContainer);
-		free(pkzip->fileName);
-		free(pkzip);
+		PKZip_Free(pkzip);
 		return NULL;
 	}
 	
-	pkzip->fileNum = 0;
+	pkzip->chainNum = 0;
 	
 	ret = PKZip_GetEndOfCentralDirectory(
 		pkzip,
 		&endOfCentralDir);
 	if (ret == -1) {
-		DirContainer_Free(pkzip->dirContainer);
-		free(pkzip->fileName);
-		SDL_RWclose(pkzip->rw);
-		free(pkzip);
+		PKZip_Free(pkzip);
 		return NULL;
 	}
 	
@@ -468,22 +469,20 @@ PKZIP_DATA *PKZip_Create(const char *file)
 	
 	pkzip->chain = malloc(sizeof(INNER_FILE));
 	if (pkzip->chain == NULL) {
-		DirContainer_Free(pkzip->dirContainer);
-		free(pkzip->fileName);
-		SDL_RWclose(pkzip->rw);
-		free(pkzip);
+		PKZip_Free(pkzip);
 		return NULL;
 	}
-	pkzip->allocatedChain = 1;
+	pkzip->chainAllocated = 1;
 	while (SDL_RWtell(pkzip->rw) < fileSize) {
-		if (pkzip->fileNum + 1 > pkzip->allocatedChain) {
-			pkzip->allocatedChain = pkzip->allocatedChain * 2;
+		if (pkzip->chainNum + 1 > pkzip->chainAllocated) {
+			needSize = pkzip->chainAllocated * 2;
 			tempptr = realloc(pkzip->chain,
-				sizeof(INNER_FILE) * pkzip->allocatedChain);
+				sizeof(INNER_FILE) * needSize);
 			if (tempptr == NULL) {
 				break;
 			}
 			pkzip->chain = (INNER_FILE*)tempptr;
+			pkzip->chainAllocated = needSize;
 		}
 		ret = PKZip_LoadNextHeader(pkzip);
 		if (ret != 0) {
@@ -500,6 +499,7 @@ SDL_Archive *PKZip_Clone(SDL_Archive *orgArchive)
 	PKZIP_DATA *pkzip;
 	PKZIP_DATA *orgPkzip;
 	SDL_Archive *archive;
+	int i;
 	
 	orgPkzip = (PKZIP_DATA*)orgArchive->data;
 	
@@ -508,38 +508,58 @@ SDL_Archive *PKZip_Clone(SDL_Archive *orgArchive)
 		return NULL;
 	}
 	
-	pkzip->fileName = (char*)malloc(strlen(orgPkzip->fileName) + 1);
-	if (pkzip->fileName == NULL) {
-		free(pkzip);
+	pkzip->arcName = NULL;
+	pkzip->dirContainer = NULL;
+	pkzip->rw = NULL;
+	pkzip->chain = NULL;
+	
+	pkzip->arcName = (char*)malloc(strlen(orgPkzip->arcName) + 1);
+	if (pkzip->arcName == NULL) {
+		PKZip_Free(pkzip);
 		return NULL;
 	}
-	strcpy(pkzip->fileName, orgPkzip->fileName);
+	strcpy(pkzip->arcName, orgPkzip->arcName);
 	
 	pkzip->chain = (INNER_FILE*)malloc(
-		sizeof(INNER_FILE) * orgPkzip->fileNum);
+		sizeof(INNER_FILE) * orgPkzip->chainNum);
 	if (pkzip->chain == NULL) {
-		free(pkzip->fileName);
-		free(pkzip);
+		PKZip_Free(pkzip);
+		return NULL;
 	}
-	memcpy(pkzip->chain, orgPkzip->chain,
-		sizeof(INNER_FILE) * orgPkzip->fileNum);
+	pkzip->chainAllocated = orgPkzip->chainNum;
 	
 	pkzip->openNumber = -1;
 	
 	pkzip->dirContainer = DirContainer_Clone(orgPkzip->dirContainer);
 	if (pkzip->dirContainer == NULL) {
-		free(pkzip->fileName);
-		free(pkzip->chain);
-		free(pkzip);
+		PKZip_Free(pkzip);
 		return NULL;
 	}
 	
+	pkzip->rw = SDL_RWFromFile(orgPkzip->arcName, "rb");
+	if (pkzip->rw == NULL) {
+		PKZip_Free(pkzip);
+		return NULL;
+	}
+	
+	for (i = 0; i < pkzip->chainNum; i++) {
+		pkzip->chain[i].fileName = NULL;
+	}
+	for (i = 0; i < orgPkzip->chainNum; i++) {
+		pkzip->chain[i].fileName =
+			malloc(strlen(orgPkzip->chain[i].fileName) + 1);
+		if (pkzip->chain[i].fileName == NULL) {
+			PKZip_Free(pkzip);
+			return NULL;
+		}
+		strcpy(pkzip->chain[i].fileName, orgPkzip->chain[i].fileName);
+		pkzip->chain[i].seek = orgPkzip->chain[i].seek;
+	}
+	pkzip->chainNum = orgPkzip->chainNum;
+	
 	archive = Archive_Alloc();
 	if (archive == NULL) {
-		DirContainer_Free(pkzip->dirContainer);
-		free(pkzip->fileName);
-		free(pkzip->chain);
-		free(pkzip);
+		PKZip_Free(pkzip);
 		return NULL;
 	}
 	
@@ -587,7 +607,7 @@ int PKZip_NumOpen(SDL_Archive *archive, const int num)
 	
 	pkzip = (PKZIP_DATA*)archive->data;
 	
-	if (num < 0 || pkzip->fileNum <= num) {
+	if (num < 0 || pkzip->chainNum <= num) {
 		return ARCHIVE_ERROR_NO_EXIST_FILE;
 	}
 	
@@ -676,7 +696,7 @@ int PKZip_GetFileNumByName(SDL_Archive *archive, const char *name)
 	
 	pkzip = (PKZIP_DATA*)archive->data;
 	
-	for (i = 0; i < pkzip->fileNum; i++) {
+	for (i = 0; i < pkzip->chainNum; i++) {
 		if (strcmp(name, pkzip->chain[i].fileName) == 0) {
 			return i;
 		}
@@ -770,21 +790,42 @@ char *PKZip_GetFileName(SDL_Archive *archive, int num)
 {
 	int absoluteIndex;
 	PKZIP_DATA *pkzip;
-	char *fileName;
 	
 	pkzip = (PKZIP_DATA*)archive->data;
 	
 	absoluteIndex = DirContainer_GetFileIndex(pkzip->dirContainer, num);
 	
-	fileName =
-		pkzip->chain[absoluteIndex].fileName;
-	return fileName;
+	return pkzip->chain[absoluteIndex].fileName;
+}
+
+
+void PKZip_Free(PKZIP_DATA *pkzip)
+{
+	int i;
+	
+	if (pkzip != NULL) {
+		if (pkzip->dirContainer) {
+			DirContainer_Free(pkzip->dirContainer);
+		}
+		if (pkzip->rw) {
+			SDL_RWclose(pkzip->rw);
+		}
+		if (pkzip->arcName) {
+			free(pkzip->arcName);
+		}
+		if (pkzip->chain) {
+			for (i = 0; i < pkzip->chainNum; i++) {
+				free(pkzip->chain[i].fileName);
+			}
+			free(pkzip->chain);
+		}
+		free(pkzip);
+	}
 }
 
 
 void PKZip_Finish(SDL_Archive *archive)
 {
-	int i;
 	PKZIP_DATA *pkzip;
 	
 	pkzip = (PKZIP_DATA*)archive->data;
@@ -793,15 +834,7 @@ void PKZip_Finish(SDL_Archive *archive)
 		Archive_Close(archive);
 	}
 	
-	if (pkzip != NULL) {
-		DirContainer_Free(pkzip->dirContainer);
-		SDL_RWclose(pkzip->rw);
-		for (i = 0; i < pkzip->fileNum; i++) {
-			free(pkzip->chain[i].fileName);
-		}
-		free(pkzip->chain);
-		free(pkzip);
-	}
+	PKZip_Free(pkzip);
 	
 	Archive_FreeMainContext(archive);
 }
